CreateDistributionCpiBuilder

Struct CreateDistributionCpiBuilder 

pub struct CreateDistributionCpiBuilder<'a, 'b> { /* private fields */ }
Instruction builder for CreateDistribution via CPI.

Accounts:

  1. [writable] distribution
  2. [] mint
  3. [writable, signer] payer
  4. [signer, optional] authority
  5. [writable] fee_wallet
  6. [signer] seed
  7. [] system_program

Implementations

Source

impl<'a, 'b> CreateDistributionCpiBuilder<'a, 'b>

pub fn new(program: &'b AccountInfo<'a>) -> Self

pub fn distribution(&mut self, distribution: &'b AccountInfo<'a>) -> &mut Self

The address of the new distribution

pub fn mint(&mut self, mint: &'b AccountInfo<'a>) -> &mut Self

The address of the mint account

pub fn payer(&mut self, payer: &'b AccountInfo<'a>) -> &mut Self

The account paying for the storage fees

pub fn authority(&mut self, authority: Option<&'b AccountInfo<'a>>) -> &mut Self

[optional account] The authority of the distribution

pub fn fee_wallet(&mut self, fee_wallet: &'b AccountInfo<'a>) -> &mut Self

The wallet where fees are sent

pub fn seed(&mut self, seed: &'b AccountInfo<'a>) -> &mut Self

The seed for the distribution

pub fn system_program( &mut self, system_program: &'b AccountInfo<'a>, ) -> &mut Self

The system program

pub fn merkle_root(&mut self, merkle_root: [u8; 32]) -> &mut Self

pub fn tree_height(&mut self, tree_height: u8) -> &mut Self

pub fn start_time(&mut self, start_time: i64) -> &mut Self

pub fn end_time(&mut self, end_time: i64) -> &mut Self

pub fn total_claimants(&mut self, total_claimants: u64) -> &mut Self

pub fn name(&mut self, name: String) -> &mut Self

pub fn distribution_type( &mut self, distribution_type: DistributionType, ) -> &mut Self

[optional argument, defaults to 'DistributionType::Wallet']

pub fn subsidize_receipts(&mut self, subsidize_receipts: bool) -> &mut Self

[optional argument, defaults to 'false']

pub fn allowed_distributor( &mut self, allowed_distributor: AllowedDistributor, ) -> &mut Self

[optional argument, defaults to 'AllowedDistributor::Permissionless']

pub fn permissioned_distributor( &mut self, permissioned_distributor: Pubkey, ) -> &mut Self

[optional argument, defaults to 'pubkey!("11111111111111111111111111111111")']

pub fn add_remaining_account( &mut self, account: &'b AccountInfo<'a>, is_writable: bool, is_signer: bool, ) -> &mut Self

Add an additional account to the instruction.

pub fn add_remaining_accounts( &mut self, accounts: &[(&'b AccountInfo<'a>, bool, bool)], ) -> &mut Self

Add additional accounts to the instruction.

Each account is represented by a tuple of the AccountInfo, a bool indicating whether the account is writable or not, and a bool indicating whether the account is a signer or not.

pub fn invoke(&self) -> ProgramResult

pub fn invoke_signed(&self, signers_seeds: &[&[&[u8]]]) -> ProgramResult