pub struct CreateDistributionInstructionArgs {
pub merkle_root: [u8; 32],
pub tree_height: u8,
pub start_time: i64,
pub end_time: i64,
pub total_claimants: u64,
pub name: String,
pub distribution_type: DistributionType,
pub subsidize_receipts: bool,
pub allowed_distributor: AllowedDistributor,
pub permissioned_distributor: Pubkey,
}Fields
merkle_root: [u8; 32]tree_height: u8start_time: i64end_time: i64total_claimants: u64name: Stringdistribution_type: DistributionTypesubsidize_receipts: boolallowed_distributor: AllowedDistributorpermissioned_distributor: PubkeyTrait Implementations
Sourceimpl BorshDeserialize for CreateDistributionInstructionArgs
impl BorshDeserialize for CreateDistributionInstructionArgs
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl Clone for CreateDistributionInstructionArgs
impl Clone for CreateDistributionInstructionArgs
Sourcefn clone(&self) -> CreateDistributionInstructionArgs
fn clone(&self) -> CreateDistributionInstructionArgs
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Eq for CreateDistributionInstructionArgs
Sourceimpl PartialEq for CreateDistributionInstructionArgs
impl PartialEq for CreateDistributionInstructionArgs
Sourcefn eq(&self, other: &CreateDistributionInstructionArgs) -> bool
fn eq(&self, other: &CreateDistributionInstructionArgs) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for CreateDistributionInstructionArgs